From 05beae43cfeb15ea89b984d36105dcdbdffd0975 Mon Sep 17 00:00:00 2001
From: Marius Cramer <m.cramer@pixcept.de>
Date: Fri, 18 Oct 2013 09:16:34 -0400
Subject: [PATCH] Resolved differences from svn merge to trunk and git master

---
 interface/web/sites/web_aliasdomain_list.php |   11 ++++-------
 1 files changed, 4 insertions(+), 7 deletions(-)

diff --git a/interface/web/sites/web_aliasdomain_list.php b/interface/web/sites/web_aliasdomain_list.php
index 1cf1b66..c5e63be 100644
--- a/interface/web/sites/web_aliasdomain_list.php
+++ b/interface/web/sites/web_aliasdomain_list.php
@@ -41,17 +41,14 @@
 * End Form configuration
 ******************************************/
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'sites')) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('sites');
 
 $app->uses('listform_actions');
 
 // Limit the results to alias domains
-$app->listform_actions->SQLExtWhere = "type = 'alias'";
-
+$app->listform_actions->SQLExtWhere = "web_domain.type = 'alias'";
+$app->listform_actions->SQLOrderBy = 'ORDER BY web_domain.domain';
 $app->listform_actions->onLoad();
 
 

--
Gitblit v1.9.1